==> downloads.html?file=gigkalender_v1.2.75_017.zip: gigkalender/news/backend_delNews.php <==
<?php
/*
    CREATIVE COMMONS - Attribution-No Derivative Works 3.0 Germany:
    - You may not alter, transform, or build upon this work.
    - Dieses Werk darf nicht bearbeitet oder in anderer Weise verändert werden.
*/
  $xUserRightDeleteNews = getCurrentUserVar('UserRightDeleteNews');
      echo '<p class="Headline">'.$L_Headline31.':</p>';
      if ( !$xUserRightDeleteNews ) { echo $L_015; }
      else
      {
        // Inhalt hier einfügen
          if (isset($_POST['delNews']))
      	 {
        	   if ($_POST['delNews']==$L_Button23)
        	   {
              $SQL_Befehl = "DELETE FROM ".$prefix."news WHERE NewsID = '$NewsID'";
              $resultat = mysqli_query($db, $SQL_Befehl);
              //$temp = DatumAusTimestamp ($Timestamp);
              if ($resultat)
              { 
                include_once ('news/functions.php');
                writeAllFeeds();
                echo $L_News_successfully_deleted;
              }
              else { echo '<span class="ErrorMessage">'.$L_ERROR_News_not_deleted.'</span><br />'; }
        	   }
        	   if ($_POST['delNews']==$L_Button24)
        	   {
              echo $L_174;
        	   }
      	 }
      	 else
      	 {
        	   echo '
              </head>
              <body>
        	   ';
        	   echo $L_172.'<br /><br />';
        	   echo '
              <form method="post" action="index.php?submenue=news&inhalt=backend_delNews" accept-charset="UTF-8">
                <fieldset>
                  <input name="delNews" id="delNews" type="submit" value="'.$L_Button23.'" class="button">
                  <input name="delNews" id="delNews" type="submit" value="'.$L_Button24.'" class="button">
                  <input name="NewsID" id="NewsID" type="hidden" value="'.$newsid.'">
                  <input type="hidden" name="http-equiv" value="backend_showAllNews">
                </fieldset>
        	     </form>
            ';
      	 }
        // Inhalt zuende
      }
    ?>

==> downloads.html?file=gigkalender_v1.2.83_039.zip: gigkalender/news/backend_delNews.php <==
<?php
/*
    CREATIVE COMMONS - Attribution-No Derivative Works 3.0 Germany:
    - You may not alter, transform, or build upon this work.
    - Dieses Werk darf nicht bearbeitet oder in anderer Weise verändert werden.
*/
  $xUserRightDeleteNews = getCurrentUserVar('UserRightDeleteNews');
      echo '<p class="Headline">'.$L_Headline31.':</p>';
      if ( !$xUserRightDeleteNews ) { echo $L_015; }
      else
      {
        // Inhalt hier einfügen
          if (isset($_POST['delNews']))
      	 {
        	   if ($_POST['delNews']==$L_Button23)
        	   {
              $SQLQuery = "DELETE FROM ".$prefix."news WHERE NewsID = '$NewsID'";
              $Result = mysqli_query($db, $SQLQuery);
              //$temp = DatumAusTimestamp ($Timestamp);
              if ($Result)
              { 
                include_once ('news/functions.php');
                writeAllFeeds();
                echo $L_News_successfully_deleted;
              }
              else { echo '<span class="ErrorMessage">'.$L_ERROR_News_not_deleted.'</span><br />'; }
        	   }
        	   if ($_POST['delNews']==$L_Button24)
        	   {
              echo $L_174;
        	   }
      	 }
      	 else
      	 {
        	   echo '
              </head>
              <body>
        	   ';
        	   echo $L_172.'<br /><br />';
        	   echo '
              <form method="post" action="index.php?submenue=news&content=backend_delNews" accept-charset="UTF-8">
                <fieldset>
                  <input name="delNews" id="delNews" type="submit" value="'.$L_Button23.'" class="button">
                  <input name="delNews" id="delNews" type="submit" value="'.$L_Button24.'" class="button">
                  <input name="NewsID" id="NewsID" type="hidden" value="'.$newsid.'">
                  <input type="hidden" name="http-equiv" value="backend_showAllNews">
                </fieldset>
        	     </form>
            ';
      	 }
        // Inhalt zuende
      }
    ?>
